
/////////////////////////////////////////////////////////
//                                                     //
//              Bold for Delphi                        //
//    Copyright (c) 2003 Borland                       //
//                                                     //
/////////////////////////////////////////////////////////

{ Global compiler directives }
{$include bold.inc}
unit BoldPersistenceHandleET;

interface

uses
  Classes,
  BoldDBInterfaces,
  EasyTable,
  BoldDatabaseAdapterET,
  BoldPersistenceHandleDB,
  BoldPersistenceHandleDB_deprecated,
  BoldETInterfaces;

type
  { forward declarations }
  TBoldPersistenceHandleET = class;

  { TBoldPersistenceHandleET }
  TBoldPersistenceHandleET = class(TBoldDBPersistenceHandle)
  private
    FDatabaseName: string;
    FDatabase: TEasyDatabase;
    FDatabaseAdapter: TBoldETDatabase;
    FEffectiveDataBase: TEasyDatabase;
    function GetEffectiveDatabase: TEasyDatabase;
    procedure SetDatabaseAdapter(const Value: TBoldETDatabase);
    procedure SetDatabase(const Value: TEasyDatabase);
    procedure SetDatabaseName(const Value: string);
    procedure SetEffectiveDatabase(const Value: TEasyDatabase);
  protected
    procedure Notification(AComponent: TComponent; Operation: TOperation); override;
    property DatabaseAdapter: TBoldETDatabase read FDatabaseAdapter write SetDatabaseAdapter;
    property EffectiveDatabase: TEasyDatabase read GetEffectiveDatabase write SetEffectiveDatabase;
    {$IFNDEF T2H}
    procedure InternalTransferproperties(const target: TBoldPersistenceHandleDB); override;
    {$ENDIF}
  public
    destructor destroy; override;
    function GetDataBaseInterface: IBoldDatabase; override;
  published
    property DatabaseName: string read FDatabaseName write SetDatabaseName;
    property Database: TEasyDatabase read FDatabase write SetDatabase;
  end deprecated;

implementation

uses
  Dialogs,
  SysUtils,
  BoldRev;

{ TBoldPersistenceHandleET }

destructor TBoldPersistenceHandleET.destroy;
begin
  Active := false;
  FreeAndNil(FEffectiveDatabase);
  FreeAndNil(FDatabaseAdapter);
  inherited;
end;

function TBoldPersistenceHandleET.GetDataBaseInterface: IBoldDatabase;
begin
  if not assigned(FDatabaseAdapter) then
    FDatabaseAdapter := TBoldETDatabase.create(EffectiveDatabase, SQLDataBaseConfig);
  result := FDataBaseAdapter;
end;

function TBoldPersistenceHandleET.GetEffectiveDatabase: TEasyDatabase;
begin
  if assigned(FDatabase) then
    result := FDatabase
  else
    raise Exception.CreateFmt('%s.GetEffectiveDatabase: SDDatabase property must be assigned', [ClassName]);
end;

procedure TBoldPersistenceHandleET.InternalTransferproperties(
  const target: TBoldPersistenceHandleDB);
var
  Adapter: TBoldDatabaseAdapterET;
  DesInfo: longint;
begin
  inherited;
  DesInfo := Target.DesignInfo;
  if not assigned(Target.DatabaseAdapter) then
  begin
    Target.DatabaseAdapter := TBoldDatabaseAdapterET.Create(Target.Owner);
    Target.DatabaseAdapter.Name := GetNewComponentName(Target.DatabaseAdapter, 'BoldDatabaseAdapterET');
    LongRec(DesInfo).Lo := LongRec(DesInfo).lo+16;
    LongRec(DesInfo).Hi := LongRec(DesInfo).hi+16;
    Target.DatabaseAdapter.DesignInfo          := DesInfo;
    showmessage('Created a new DatabaseAdapterET');
  end
  else if not (target.DatabaseAdapter is tBoldDatabaseAdapterET) then
    raise Exception.CreateFmt('The persistencehandle is connected to a %s, properties can only be transfered to a TBoldDatabaseAdapterET', [target.DatabaseAdapter.ClassName] );

  Adapter := target.DatabaseAdapter as tBoldDatabaseAdapterET;
  if assigned(Database) then
    Adapter.DataBase := Database;

  if not assigned(Adapter.Database) then
  begin
    Adapter.DataBase := TEasyDatabase.Create(Target.owner);
    Adapter.DataBase.Name := GetNewComponentName(Adapter.DataBase, 'SDDatabase');
    showmessage('Created a new Database');
    LongRec(DesInfo).Lo := LongRec(DesInfo).lo+16;
    LongRec(DesInfo).Hi := LongRec(DesInfo).hi+16;
    Adapter.DataBase.DesignInfo          := DesInfo;
  end;
end;

procedure TBoldPersistenceHandleET.Notification(AComponent: TComponent; Operation: TOperation);
begin
  inherited;
  if (aComponent = FDatabase) and (Operation = opRemove) then
  begin
    if aComponent = EffectiveDatabase then
    begin
      Active := false;
      FDatabaseAdapter := nil;
    end;
    FDatabase := nil;
  end;
end;

procedure TBoldPersistenceHandleET.SetDataBase(const Value: TEasyDatabase);
begin
  if FDatabase <> Value then
  begin
    if assigned(FEffectiveDatabase) then
    begin
      FreeAndNil(FEffectiveDatabase);
      FreeAndNil(FDatabaseAdapter);
    end;
    FDatabase := Value;
    if assigned(FDatabase) then
      FDatabase.FreeNotification(self);
  end;
end;

procedure TBoldPersistenceHandleET.SetDatabaseAdapter(const Value: TBoldETDatabase);
begin
  FDatabaseAdapter := Value;
end;

procedure TBoldPersistenceHandleET.SetDatabaseName(const Value: string);
begin
  FDatabaseName := Value;
end;

procedure TBoldPersistenceHandleET.SetEffectiveDataBase(const Value: TEasyDatabase);
begin
  FEffectiveDatabase := Value;
end;

initialization

end.